Skip to contents

Returns the range of years for which enrollment data is available from Alaska DEED's statistics portal.

Usage

get_available_years()

Value

Named list with min_year, max_year, and description

Details

Data is downloaded directly from: https://education.alaska.gov/Stats/enrollment/

Examples

get_available_years()
#> $min_year
#> [1] 2021
#> 
#> $max_year
#> [1] 2025
#> 
#> $description
#> [1] "Alaska DEED enrollment data availability:\n- 2021-2025: Excel files from DEED Statistics Portal\n  (Enrollment by School by Grade & Enrollment by School by Ethnicity)\n\nData source: https://education.alaska.gov/Stats/enrollment/\n\nNote: Earlier years (2019-2020) may have existed but files are no longer\navailable on the DEED website. Years prior to that may be available as\nPDF reports but are not supported for automated download."
#>