Imports school directory data from a locally saved file. Use this function when automatic downloads from the DCCED ArcGIS API are not available.
Details
You can export school directory data from the DCCED open data portal: https://dcra-cdo-dcced.opendata.arcgis.com/
The DCCED portal provides data from 4 layers: School Enrollment View,
Alaska Schools, District Contacts, and School Contacts. For the richest
directory data, use fetch_directory() which queries all 4 layers.
This function processes a single exported file at a time.